@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2015-2018 CERN.
+# Copyright (C) 2015-2022 CERN.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -327,11 +327,11 @@ record has been correctly modified:
 See :doc:`api` for extensive API documentation.
 """
 
-from __future__ import absolute_import, print_function
 
 from .api import Record
 from .ext import InvenioRecords
-from .version import __version__
+
+__version__ = '1.7.1'
 
 __all__ = (
     'InvenioRecords',
