@@ -2,6 +2,7 @@
 #
 # This file is part of Invenio.
 # Copyright (C) 2020 CERN.
+# Copyright (C) 2021 RERO.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -9,6 +10,7 @@
 """The core of the system fields implementation."""
 
 import inspect
+import warnings
 
 from ..dictutils import dict_lookup, parse_lookup_key
 from ..extensions import ExtensionMixin, RecordExtension, RecordMeta
@@ -257,18 +259,70 @@ class SystemFieldsExt(RecordExtension):
     def post_init(self, record, data, model=None, **kwargs):
         """Called when a new record instance is initialized."""
         # Special treatment for post_init (also has special implementation
-        # in in SystemField)
+        # in SystemField)
         for attr_name, field in self.declared_fields.items():
             field_data = kwargs.get(field.attr_name)
             field.post_init(record, data, model=model, field_data=field_data)
 
-    def pre_dump(self, *args, **kwargs):
+    def pre_dump(self, record, data, dumper=None):
         """Called before a record is dumped."""
-        self._run('pre_dump', *args, **kwargs)
+        for field in self.declared_fields.values():
+            pre_dump_params = inspect.signature(field.pre_dump).parameters
+            if 'data' in pre_dump_params:
+                field.pre_dump(record, data, dumper=dumper)
+            else:
+                # TODO: Remove in v1.6.0 or later
+                warnings.warn(
+                   "The pre_dump hook must take a positional argument data.",
+                   DeprecationWarning
+                )
+                field.pre_dump(record, dumper=dumper)
 
-    def post_load(self, *args, **kwargs):
+    def post_dump(self, record, data, dumper=None):
+        """Called after a record is dumped."""
+        for field in self.declared_fields.values():
+            post_dump_params = inspect.signature(field.post_dump).parameters
+            if 'data' in post_dump_params:
+                field.post_dump(record, data, dumper=dumper)
+            else:
+                # TODO: Remove in v1.6.0 or later
+                warnings.warn(
+                   "The post_dump hook must take a positional argument data.",
+                   DeprecationWarning
+                )
+                field.post_dump(record, dumper=dumper)
+
+    def pre_load(self, data, loader=None):
+        """Called before a record is loaded."""
+        for field in self.declared_fields.values():
+            pre_load_params = inspect.signature(field.pre_load).parameters
+            if 'data' in pre_load_params:
+                field.pre_load(data, loader=loader)
+            else:
+                # TODO: Remove in v1.6.0 or later
+                warnings.warn(
+                   "The pre_load hook must take a positional argument data.",
+                   DeprecationWarning
+                )
+                field.pre_load(loader=loader)
+
+    def post_load(self, record, data, loader=None):
         """Called after a record is loaded."""
-        self._run('post_load', *args, **kwargs)
+        for field in self.declared_fields.values():
+            post_load_params = inspect.signature(field.post_load).parameters
+            if 'data' in post_load_params:
+                field.post_load(record, data, loader=loader)
+            else:
+                # TODO: Remove in v1.6.0 or later
+                warnings.warn(
+                   "The post_load hook must take a positional argument data.",
+                   DeprecationWarning
+                )
+                field.post_load(record, loader=loader)
+
+    def pre_create(self, *args, **kwargs):
+        """Called after a record is created."""
+        self._run('pre_create', *args, **kwargs)
 
     def post_create(self, *args, **kwargs):
         """Called after a record is created."""
@@ -278,6 +332,10 @@ class SystemFieldsExt(RecordExtension):
         """Called before a record is committed."""
         self._run('pre_commit', *args, **kwargs)
 
+    def post_commit(self, *args, **kwargs):
+        """Called after a record is commited."""
+        self._run('post_commit', *args, **kwargs)
+
     def pre_delete(self, *args, **kwargs):
         """Called before a record is deleted."""
         self._run('pre_delete', *args, **kwargs)
