@@ -22,15 +22,17 @@ The field consists of:
 from .errors import InvalidCheckValue, InvalidRelationValue, RelationError
 from .field import RelationsField
 from .mapping import RelationsMapping
+from .modelrelations import ModelRelation
 from .relations import ListRelation, NestedListRelation, PKListRelation, \
     PKNestedListRelation, PKRelation, RelationBase
 from .results import RelationListResult, RelationNestedListResult, \
     RelationResult
 
 __all__ = (
-    'InvalidRelationValue',
     'InvalidCheckValue',
+    'InvalidRelationValue',
     'ListRelation',
+    'ModelRelation',
     'NestedListRelation',
     'PKListRelation',
     'PKNestedListRelation',
